import csv
from classWall import Wall, Seed, BigSeed
from random import randint as rnd


class Field:
    width = 26
    height = 50
    padding_x = 10
    padding_y = 40

    def __init__(self):
        self.width = 26
        self.height = 50
        self.field = []
        self.ghost_spawns = []
        self.load_csv(path="default_map.csv")
        self.fill_map()  # format: [x, y]

    def load_csv(self, path: str) -> None:
        with open(path) as f:
            for line in f:
                if line[-1] == '\n':
                    line = line[:-1]
                self.field.append(list(line.split(';')))
        print(*self.field, sep='\n')

    def to_csv(self, path: str):
        with open('Field.csv', 'w') as f:
            writer = csv.writer(f)
            for row in self.field:
                writer.writerow(row)

    def draw(self):
        self.draw_objects()

    def draw_objects(self):
        for i in range(self.height):
            for j in range(self.width):
                if type(self.field[i][j]) != str:
                    self.field[i][j].draw(j + 1, i + 1)

    def eat_seed(self, i: int, j: int):
        tmp = self.field[i][j]
        self.field[i][j] = 'nothing'
        # returns 10 for eating seed and 20 for eating bigSeed
        # removes seed from field
        # is field[i][j] is not a seed returns -1
        if tmp == Seed():
            return 10
        elif tmp == BigSeed():
            return 20
        else:
            return -1

    def fill_map(self):
        for i in range(self.height):
            for j in range(self.width):
                if self.field[i][j] == 'w':
                    tmp = Wall()
                    self.field[i][j] = tmp
                elif self.field[i][j] == "f":
                    chance = rnd(1, 100)
                    if chance == 50:
                        tmp = BigSeed()
                        self.field[i][j] = tmp
                    else:
                        tmp = Seed()
                        self.field[i][j] = tmp
                elif self.field[i][j] == 'n':
                    self.field[i][j] = 'nothing'
                elif self.field[i][j] == 'g':
                    self.field[i][j] = 'Ghost spawn'
                    self.ghost_spawns.append([j, i])
                else:
                    self.field[i][j] = ''

    def get_ghost_spawns(self) -> list[list[int]]:
        """Функция нужна для инициализации призраков"""
        return self.ghost_spawns
